@@ -11,6 +11,8 @@ REMARKS = "remarks"
 START_TIME = "start time"
 END_TIME = "end time"
 TIME_ZERO = "time zero"
+TIME_INCREMENT = "time increment"
+TIME_UNITS = "time units"
 NUMBER_OF_RECORDS = "number of records"
 DATA_DESCRIPTION = "data description"
 FILE_TYPE = "file type"
@@ -20,6 +22,7 @@ CHANNELS = "channels"
 CHANNEL_DETAIL = "channel detail"
 FORMAT = "format"
 CONTINUED = "continued"
+PAD = "pad"
 
 # *ADMINISTRATION keys
 MISSION = "mission"
